==> jc-1.4.0.tar.gz: java/security/spec/PKCS8EncodedKeySpec.h <==
// public class java.security.spec.PKCS8EncodedKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 76558bda43f0601d java_security_spec_EncodedKeySpec
// @dep_class 1e3298bbc69203d6 java_security_spec_PKCS8EncodedKeySpec

// header file dependencies
// @dep_header java_security_spec_EncodedKeySpec

#include "java/security/spec/EncodedKeySpec.h"

#ifndef _JC_java_security_spec_PKCS8EncodedKeySpec_H_
#define _JC_java_security_spec_PKCS8EncodedKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$sub_refs	_jc_java_security_spec_PKCS8EncodedKeySpec$sub_refs;
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$sub_nonrefs	_jc_java_security_spec_PKCS8EncodedKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$refs	_jc_java_security_spec_PKCS8EncodedKeySpec$refs;
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$nonrefs	_jc_java_security_spec_PKCS8EncodedKeySpec$nonrefs;
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$object	_jc_java_security_spec_PKCS8EncodedKeySpec$object;

typedef const struct _jc_java_security_spec_PKCS8EncodedKeySpec$vmethods	_jc_java_security_spec_PKCS8EncodedKeySpec$vmethods;
typedef const struct _jc_java_security_spec_PKCS8EncodedKeySpec$vtable	_jc_java_security_spec_PKCS8EncodedKeySpec$vtable;
typedef const struct _jc_java_security_spec_PKCS8EncodedKeySpec$vtype	_jc_java_security_spec_PKCS8EncodedKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_PKCS8EncodedKeySpec$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *, struct _jc_byte_array *);

// Virtual methods
extern _jc_byte_array *_jc_java_security_spec_PKCS8EncodedKeySpec$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_spec_PKCS8EncodedKeySpec$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_PKCS8EncodedKeySpec$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_java_security_spec_PKCS8EncodedKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b;

// Virtual methods structure
struct _jc_java_security_spec_PKCS8EncodedKeySpec$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *);
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *);
};

// Vtable
struct _jc_java_security_spec_PKCS8EncodedKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_EncodedKeySpec$vmethods	java_security_spec_EncodedKeySpec;
	_jc_java_security_spec_PKCS8EncodedKeySpec$vmethods	java_security_spec_PKCS8EncodedKeySpec;
};

// Vtype
struct _jc_java_security_spec_PKCS8EncodedKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_PKCS8EncodedKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_PKCS8EncodedKeySpec$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_spec_PKCS8EncodedKeySpec$refs {
    _jc_java_security_spec_PKCS8EncodedKeySpec$sub_refs	java_security_spec_PKCS8EncodedKeySpec;
    _jc_java_security_spec_EncodedKeySpec$sub_refs	java_security_spec_EncodedKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_PKCS8EncodedKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_PKCS8EncodedKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_EncodedKeySpec$sub_nonrefs	java_security_spec_EncodedKeySpec;
    _jc_java_security_spec_PKCS8EncodedKeySpec$sub_nonrefs	java_security_spec_PKCS8EncodedKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_PKCS8EncodedKeySpec$object {
	_jc_java_security_spec_PKCS8EncodedKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_PKCS8EncodedKeySpec$vtype	*vtype;
	_jc_java_security_spec_PKCS8EncodedKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_PKCS8EncodedKeySpec$vtype _jc_java_security_spec_PKCS8EncodedKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_PKCS8EncodedKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_PKCS8EncodedKeySpec$class_object;

#endif	/* _JC_java_security_spec_PKCS8EncodedKeySpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/PKCS8EncodedKeySpec.h <==
// public class java.security.spec.PKCS8EncodedKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 76558bda43f0601d java_security_spec_EncodedKeySpec
// @dep_class 1e3298bbc69203d6 java_security_spec_PKCS8EncodedKeySpec

// header file dependencies
// @dep_header java_security_spec_EncodedKeySpec

#include "java/security/spec/EncodedKeySpec.h"

#ifndef _JC_java_security_spec_PKCS8EncodedKeySpec_H_
#define _JC_java_security_spec_PKCS8EncodedKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$sub_refs	_jc_java_security_spec_PKCS8EncodedKeySpec$sub_refs;
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$sub_nonrefs	_jc_java_security_spec_PKCS8EncodedKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$refs	_jc_java_security_spec_PKCS8EncodedKeySpec$refs;
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$nonrefs	_jc_java_security_spec_PKCS8EncodedKeySpec$nonrefs;
typedef struct _jc_java_security_spec_PKCS8EncodedKeySpec$object	_jc_java_security_spec_PKCS8EncodedKeySpec$object;

typedef const struct _jc_java_security_spec_PKCS8EncodedKeySpec$vmethods	_jc_java_security_spec_PKCS8EncodedKeySpec$vmethods;
typedef const struct _jc_java_security_spec_PKCS8EncodedKeySpec$vtable	_jc_java_security_spec_PKCS8EncodedKeySpec$vtable;
typedef const struct _jc_java_security_spec_PKCS8EncodedKeySpec$vtype	_jc_java_security_spec_PKCS8EncodedKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_PKCS8EncodedKeySpec$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_java_security_spec_PKCS8EncodedKeySpec$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_spec_PKCS8EncodedKeySpec$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_PKCS8EncodedKeySpec$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_java_security_spec_PKCS8EncodedKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b;

// Virtual methods structure
struct _jc_java_security_spec_PKCS8EncodedKeySpec$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_java_security_spec_PKCS8EncodedKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_PKCS8EncodedKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_EncodedKeySpec$vmethods	java_security_spec_EncodedKeySpec;
	_jc_java_security_spec_PKCS8EncodedKeySpec$vmethods	java_security_spec_PKCS8EncodedKeySpec;
};

// Vtype
struct _jc_java_security_spec_PKCS8EncodedKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_PKCS8EncodedKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_PKCS8EncodedKeySpec$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_spec_PKCS8EncodedKeySpec$refs {
    _jc_java_security_spec_PKCS8EncodedKeySpec$sub_refs	java_security_spec_PKCS8EncodedKeySpec;
    _jc_java_security_spec_EncodedKeySpec$sub_refs	java_security_spec_EncodedKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_PKCS8EncodedKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_PKCS8EncodedKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_EncodedKeySpec$sub_nonrefs	java_security_spec_EncodedKeySpec;
    _jc_java_security_spec_PKCS8EncodedKeySpec$sub_nonrefs	java_security_spec_PKCS8EncodedKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_PKCS8EncodedKeySpec$object {
	_jc_java_security_spec_PKCS8EncodedKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_PKCS8EncodedKeySpec$vtype	*vtype;
	_jc_java_security_spec_PKCS8EncodedKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_PKCS8EncodedKeySpec$vtype _jc_java_security_spec_PKCS8EncodedKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_PKCS8EncodedKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_PKCS8EncodedKeySpec$class_object;

#endif	/* _JC_java_security_spec_PKCS8EncodedKeySpec_H_ */
